@@ -61,13 +61,17 @@ if (!defined('E_USER_DEPRECATED')) {
 /**
  * phpCAS version. accessible for the user by phpCAS::getVersion().
  */
-define('PHPCAS_VERSION', '1.3.6');
+define('PHPCAS_VERSION', '1.3.8');
 
 /**
  * @addtogroup public
  * @{
  */
 
+/**
+ * phpCAS supported protocols. accessible for the user by phpCAS::getSupportedProtocols().
+ */
+
 /**
  * CAS version 1.0
  */
@@ -244,6 +248,7 @@ define("PHPCAS_LANG_DEFAULT", PHPCAS_LANG_ENGLISH);
 
 /**
  * The default directory for the debug file under Unix.
+ * @return  string directory for the debug file
  */
 function gettmpdir() {
 if (!empty($_ENV['TMP'])) { return realpath($_ENV['TMP']); }
@@ -287,6 +292,7 @@ class phpCAS
     private static $_PHPCAS_CLIENT;
 
     /**
+     * @var array
      * This variable is used to store where the initializer is called from
      * (to print a comprehensive error in case of multiple calls).
      *
@@ -295,6 +301,7 @@ class phpCAS
     private static $_PHPCAS_INIT_CALL;
 
     /**
+     * @var array
      * This variable is used to store phpCAS debug mode.
      *
      * @hideinitializer
@@ -325,12 +332,12 @@ class phpCAS
      *
      * @param string $server_version  the version of the CAS server
      * @param string $server_hostname the hostname of the CAS server
-     * @param string $server_port     the port the CAS server is running on
+     * @param int    $server_port     the port the CAS server is running on
      * @param string $server_uri      the URI the CAS server is responding on
      * @param bool   $changeSessionID Allow phpCAS to change the session_id (Single
      * Sign Out/handleLogoutRequests is based on that change)
      *
-     * @return a newly created CAS_Client object
+     * @return void a newly created CAS_Client object
      * @note Only one of the phpCAS::client() and phpCAS::proxy functions should be
      * called, only once, and before all other methods (except phpCAS::getVersion()
      * and phpCAS::setDebug()).
@@ -369,12 +376,12 @@ class phpCAS
      *
      * @param string $server_version  the version of the CAS server
      * @param string $server_hostname the hostname of the CAS server
-     * @param string $server_port     the port the CAS server is running on
+     * @param int    $server_port     the port the CAS server is running on
      * @param string $server_uri      the URI the CAS server is responding on
      * @param bool   $changeSessionID Allow phpCAS to change the session_id (Single
      * Sign Out/handleLogoutRequests is based on that change)
      *
-     * @return a newly created CAS_Client object
+     * @return void a newly created CAS_Client object
      * @note Only one of the phpCAS::client() and phpCAS::proxy functions should be
      * called, only once, and before all other methods (except phpCAS::getVersion()
      * and phpCAS::setDebug()).
@@ -491,7 +498,7 @@ class phpCAS
     /**
      * Show is verbose mode is on
      *
-     * @return boot verbose
+     * @return bool verbose
      */
     public static function getVerbose()
     {
@@ -631,7 +638,7 @@ class phpCAS
      * This method is used to indicate the end of the execution of a function in
      * debug mode.
      *
-     * @param string $res the result of the function
+     * @param mixed $res the result of the function
      *
      * @return void
      */
@@ -642,7 +649,6 @@ class phpCAS
         } else {
             self::$_PHPCAS_DEBUG['indent']--;
         }
-        $dbg = debug_backtrace();
         $str = '';
         if (is_object($res)) {
             $str .= '<= ' . get_class($res);
@@ -709,13 +715,29 @@ class phpCAS
     /**
      * This method returns the phpCAS version.
      *
-     * @return the phpCAS version.
+     * @return string the phpCAS version.
      */
     public static function getVersion()
     {
         return PHPCAS_VERSION;
     }
 
+    /**
+     * This method returns supported protocols.
+     *
+     * @return array an array of all supported protocols. Use internal protocol name as array key.
+     */
+    public static function getSupportedProtocols()
+    {
+        $supportedProtocols = array();
+        $supportedProtocols[CAS_VERSION_1_0] = 'CAS 1.0';
+        $supportedProtocols[CAS_VERSION_2_0] = 'CAS 2.0';
+        $supportedProtocols[CAS_VERSION_3_0] = 'CAS 3.0';
+        $supportedProtocols[SAML_VERSION_1_1] = 'SAML 1.1';
+
+        return $supportedProtocols;
+    }
+
     /** @} */
     // ########################################################################
     //  HTML OUTPUT
@@ -773,8 +795,8 @@ class phpCAS
     /**
      * This method can be used to set a custom PGT storage object.
      *
-     * @param CAS_PGTStorage $storage a PGT storage object that inherits from the
-     * CAS_PGTStorage class
+     * @param CAS_PGTStorage_AbstractStorage $storage a PGT storage object that inherits from the
+     * CAS_PGTStorage_AbstractStorage class
      *
      * @return void
      */
@@ -903,7 +925,7 @@ class phpCAS
      * This method is used to access an HTTP[S] service.
      *
      * @param string $url       the service to access.
-     * @param string &$err_code an error code Possible values are
+     * @param int &$err_code an error code Possible values are
      * PHPCAS_SERVICE_OK (on success), PHPCAS_SERVICE_PT_NO_SERVER_RESPONSE,
      * PHPCAS_SERVICE_PT_BAD_SERVER_RESPONSE, PHPCAS_SERVICE_PT_FAILURE,
      * PHPCAS_SERVICE_NOT_AVAILABLE.
@@ -936,7 +958,7 @@ class phpCAS
      * including the mailing box for IMAP URLs, as accepted by imap_open().
      * @param string $service   a string giving for CAS retrieve Proxy ticket
      * @param string $flags     options given to imap_open().
-     * @param string &$err_code an error code Possible values are
+     * @param int &$err_code an error code Possible values are
      * PHPCAS_SERVICE_OK (on success), PHPCAS_SERVICE_PT_NO_SERVER_RESPONSE,
      * PHPCAS_SERVICE_PT_BAD_SERVER_RESPONSE, PHPCAS_SERVICE_PT_FAILURE,
      * PHPCAS_SERVICE_NOT_AVAILABLE.
@@ -944,7 +966,7 @@ class phpCAS
      * @param string &$pt       the Proxy Ticket (PT) retrieved from the CAS
      * server to access the URL on success, false on error).
      *
-     * @return object IMAP stream on success, false otherwise (in this later
+     * @return object|false IMAP stream on success, false otherwise (in this later
      * case, $err_code gives the reason why it failed and $err_msg contains an
      * error message).
      */
@@ -1027,7 +1049,7 @@ class phpCAS
      * logs in (such as registering an account, performing logging, etc), register
      * a callback function here.
      *
-     * @param string $function       Callback function
+     * @param callable $function       Callback function
      * @param array  $additionalArgs optional array of arguments
      *
      * @return void
@@ -1048,7 +1070,7 @@ class phpCAS
      * applications that manage their own sessions (rather than letting phpCAS
      * start and destroy the session).
      *
-     * @param string $function       Callback function
+     * @param callable $function       Callback function
      * @param array  $additionalArgs optional array of arguments
      *
      * @return void
@@ -1066,7 +1088,7 @@ class phpCAS
      * determined by a cas gateway call.(cas login call without any interactive
      * prompt)
      *
-     * @return true when the user is authenticated, false when a previous
+     * @return bool true when the user is authenticated, false when a previous
      * gateway login failed or the function will not return if the user is
      * redirected to the cas server for a gateway login attempt
      */
@@ -1134,7 +1156,7 @@ class phpCAS
      * This method is called to check if the user is authenticated (previously or by
      * tickets given in the URL).
      *
-     * @return true when the user is authenticated.
+     * @return bool true when the user is authenticated.
      */
     public static function isAuthenticated()
     {
@@ -1269,7 +1291,7 @@ class phpCAS
      *
      * @return void
      */
-    public static function handleLogoutRequests($check_client = true, $allowed_clients = false)
+    public static function handleLogoutRequests($check_client = true, $allowed_clients = array())
     {
         phpCAS::_validateClientExists();
 
@@ -1278,9 +1300,8 @@ class phpCAS
 
     /**
      * This method returns the URL to be used to login.
-     * or phpCAS::isAuthenticated().
      *
-     * @return the login name of the authenticated user
+     * @return string the login URL
      */
     public static function getServerLoginURL()
     {
@@ -1385,10 +1406,9 @@ class phpCAS
     }
 
     /**
-     * This method returns the URL to be used to login.
-     * or phpCAS::isAuthenticated().
+     * This method returns the URL to be used to logout.
      *
-     * @return the login name of the authenticated user
+     * @return string the URL to use to log out
      */
     public static function getServerLogoutURL()
     {
@@ -1592,7 +1612,7 @@ class phpCAS
      * Retrieve a Proxy Ticket from the CAS server.
      *
      * @param string $target_service Url string of service to proxy
-     * @param string &$err_code      error code
+     * @param int &$err_code      error code
      * @param string &$err_msg       error message
      *
      * @return string Proxy Ticket
@@ -2012,4 +2032,3 @@ class phpCAS
 /**
  * @example example_advanced_saml11.php
  */
-?>
